package com.jiuqi.util.hardware;

import com.jiuqi.util.JqLib;
import com.jiuqi.util.SortedList;
import com.jiuqi.util.StringUtils;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

/* loaded from: com_jiuqi_util_hardware.jar:com/jiuqi/util/hardware/HardwareUtil.class */
public final class HardwareUtil {
    private static final int CODE_SEED = 151;

    public static final String getMachineCode(String softFlag) throws Exception {
        String code = String.valueOf(softFlag) + "@" + getMacAddress();
        MessageDigest md5 = MessageDigest.getInstance("md5");
        byte[] data = md5.digest(code.getBytes());
        String md5Data = JqLib.bytesToHexString(encodeData(data));
        String machineCode = "";
        int i = 0;
        while (i < md5Data.length() - 4) {
            machineCode = String.valueOf(machineCode) + md5Data.substring(i, i + 4) + "-";
            i += 4;
        }
        return String.valueOf(machineCode) + md5Data.substring(i, md5Data.length());
    }

    public static final byte[] getMachineSign(String category) {
        byte[] codeBytes;
        try {
            String macAddr = getMacAddress();
            if (StringUtils.isEmpty(macAddr)) {
                return null;
            }
            String code = String.valueOf(category) + "@" + macAddr;
            try {
                codeBytes = code.getBytes("UTF-8");
            } catch (UnsupportedEncodingException unused) {
                codeBytes = code.getBytes();
            }
            try {
                MessageDigest md5 = MessageDigest.getInstance("MD5");
                byte[] data = md5.digest(codeBytes);
                return encodeData(data);
            } catch (NoSuchAlgorithmException unused2) {
                return null;
            }
        } catch (Exception unused3) {
            return null;
        }
    }

    private static byte[] encodeData(byte[] data) {
        if (data == null) {
            return null;
        }
        int newSize = data.length / 2;
        byte[] result = new byte[newSize];
        for (int i = 0; i < newSize; i++) {
            result[i] = (byte) ((data[i * 2] ^ (CODE_SEED + data[(i * 2) + 1])) ^ (-152));
        }
        return result;
    }

    public static String getMacAddress() throws Exception {
        String os = System.getProperty("os.name");
        if (os.startsWith("Windows")) {
            return getWindowsMacAddresses();
        }
        if (os.startsWith("Linux")) {
            return getLinuxMacAddresses();
        }
        if (os.startsWith("HP-UX")) {
            return getHPUXMacAddresses();
        }
        return "";
    }

    private static String getWindowsMacAddresses() throws IOException {
        String ipCommandResponse = windowsRunIpConfigCommand();
        return windowsParseMacAddress(ipCommandResponse);
    }

    private static String windowsRunIpConfigCommand() throws IOException {
        Process p = Runtime.getRuntime().exec("ipconfig /all");
        return readInputText(p);
    }

    private static String readInputText(Process p) throws IOException {
        StringBuffer buffer = new StringBuffer();
        BufferedReader reader = new BufferedReader(new InputStreamReader(p.getInputStream()));
        while (true) {
            String line = reader.readLine();
            if (line != null) {
                buffer.append(line);
                buffer.append(StringUtils.LINE_SEPARATOR);
            } else {
                return buffer.toString();
            }
        }
    }

    private static String windowsParseMacAddress(String ipConfigResponse) {
        StringTokenizer stringTokenizer = new StringTokenizer(ipConfigResponse, "\n");
        SortedList buffer = new SortedList();
        while (stringTokenizer.hasMoreTokens()) {
            String line = stringTokenizer.nextToken().trim();
            if (line.startsWith("Physical") || line.startsWith("物理地址")) {
                int p = line.lastIndexOf(58);
                String macAddr = p + 1 >= line.length() ? null : line.substring(p + 1).trim();
                if (!StringUtils.isEmpty(macAddr) && !buffer.contains(macAddr)) {
                    buffer.add(macAddr);
                }
            }
        }
        return catMacAddrs(buffer);
    }

    private static String catMacAddrs(List buffer) {
        if (buffer.size() == 0) {
            return null;
        }
        StringBuffer result = new StringBuffer((String) buffer.get(0));
        for (int i = 1; i < buffer.size(); i++) {
            result.append(';').append(((String) buffer.get(i)).toUpperCase());
        }
        return result.toString();
    }

    private static String getLinuxMacAddresses() throws Exception {
        String ifCommandResponse = linuxRunIfConfigCommand();
        return linuxParseMacAddress(ifCommandResponse);
    }

    private static String linuxRunIfConfigCommand() throws IOException {
        Process p = Runtime.getRuntime().exec("ifconfig");
        return readInputText(p);
    }

    private static String linuxParseMacAddress(String ifCommandResponse) {
        StringTokenizer stringTokenizer = new StringTokenizer(ifCommandResponse, "\n");
        SortedList buffer = new SortedList();
        while (stringTokenizer.hasMoreTokens()) {
            String line = stringTokenizer.nextToken();
            int macPos = line.indexOf("HWaddr");
            if (macPos != -1) {
                String macAddr = line.substring(macPos + 1).trim();
                if (macAddr.length() == 17 && !buffer.contains(macAddr)) {
                    buffer.add(macAddr);
                }
            }
        }
        return catMacAddrs(buffer);
    }

    private static String getHPUXMacAddresses() throws IOException {
        String lanscanCommandResponse = hpUXRunLanscanCommmand();
        return hpUXParseMacAddress(lanscanCommandResponse);
    }

    private static String hpUXRunLanscanCommmand() throws IOException {
        Process p = Runtime.getRuntime().exec("lanscan");
        return readInputText(p);
    }

    private static String hpUXParseMacAddress(String lanscanCommandResponse) {
        StringTokenizer stringTokenizer = new StringTokenizer(lanscanCommandResponse, "\n");
        ArrayList buffer = new ArrayList();
        while (stringTokenizer.hasMoreTokens()) {
            String line = stringTokenizer.nextToken().trim();
            int index = line.indexOf("0x");
            if (index != -1) {
                String macAddr = line.substring(index + 2, index + 2 + 12);
                if (!buffer.contains(macAddr)) {
                    buffer.add(macAddr);
                }
            }
        }
        return catMacAddrs(buffer);
    }
}
